==> bluefish_0.3.5.orig.tar.gz: bluefish-0.3.5/src/interface.h <==
/* Bluefish HTML Editor
 * interface.h - interface stuff
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* Changes by Antti-Juhani Kaijanaho <gaia@iki.fi> on 1999-10-20  */

#ifndef __INTERFACE_H_
#define __INTERFACE_H_

#ifndef __MENUFACTORY_H__
#define __MENUFACTORY_H__
#endif

/* #include <stdlib.h> */

#include <glib.h>
#include <gtk/gtkwidget.h>


/* statusbar message times 
 * the time to use (using these defines)
 * 3000 for a normal message
 * 6000 for a warning message
 * 12000 for a bug, severe error, critical situations etc.
 */
#define NORMAL_MESSAGE 3000
#define IMPORTANT_MESSAGE 6000
#define CRITICAL_MESSAGE 12000

/* the handle boxes where the toolbars can be added to 
   they are packed in the right place in interface.c, the 
   menubars are added in toolbars.c */
extern GtkWidget *cust_handle_box, *handle_box, *html_handle_box;

extern GtkWidget *apply_font_style(GtkWidget *this_widget, gchar *fontstring);
extern void statusbar_message (gpointer message, gint time);
extern void notebook_changed (void);
extern void destroy_current_document (void);
extern void replace_text(const gchar *newstring, gint pos, gint len);
extern void insert_text (const gchar * before, const gchar * after);
extern filestruct *new_document (void);
extern void make_main_window (void);
extern void startup (void);

#endif	/* __INTERFACE_H_ */

==> bluefish-0.4pre8.tar.gz: bluefish-0.4pre8/src/interface.h <==
/* Bluefish HTML Editor
 * interface.h - interface stuff
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* Changes by Antti-Juhani Kaijanaho <gaia@iki.fi> on 1999-10-20  */

#ifndef __INTERFACE_H_
#define __INTERFACE_H_

/* statusbar message times 
 * the time to use (using these defines)
 * 3000 for a normal message
 * 6000 for a warning message
 * 12000 for a bug, severe error, critical situations etc.
 */
#define NORMAL_MESSAGE 3000
#define IMPORTANT_MESSAGE 6000
#define CRITICAL_MESSAGE 12000

/* the handle boxes where the toolbars can be added to 
   they are packed in the right place in interface.c, the 
   menubars are added in toolbars.c */
extern GtkWidget *cust_handle_box, *handle_box, *html_handle_box;

void statusbar_message(gpointer message, gint time);
gint statusbar_remove(gpointer message_id);
gint bf_statusbar_message(gpointer message);
void notebook_next_document_cb(GtkWidget *widget, gpointer data);
void notebook_prev_document_cb(GtkWidget *widget, gpointer data);
void switch_to_document(gpointer data);
void notebook_changed(void);
void notebook_set_tab_pos(gchar * position);
void startup(void);
void show_about_window_cb(GtkWidget * w, gpointer data);


#endif							/* __INTERFACE_H_ */
